==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QAudioEncoderSettingsControl_shell.h <==
#ifndef QAUDIOENCODERSETTINGSCONTROL_SHELL_H
#define QAUDIOENCODERSETTINGSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudioencodersettingscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaencodersettings.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QAudioEncoderSettingsControl_shell : public QAudioEncoderSettingsControl, public QtJambiShellInterface
{
public:
    QAudioEncoderSettingsControl_shell(QObject* parent0 = nullptr);
    ~QAudioEncoderSettingsControl_shell() override;

    QAudioEncoderSettings audioSettings() const override;
    void childEvent(QChildEvent* event0) override;
    QString codecDescription(const QString& codecName0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setAudioSettings(const QAudioEncoderSettings& settings0) override;
    QStringList supportedAudioCodecs() const override;
    QList<int> supportedSampleRates(const QAudioEncoderSettings& settings0, bool* continuous1) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioEncoderSettingsControl_access : public QAudioEncoderSettingsControl
{
    jobject __qt_audioSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_codecDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring codecName0) const;
    void __qt_setAudioSettings_cref_QAudioEncoderSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0);
    jobject __qt_supportedAudioCodecs(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_supportedSampleRates_cref_QAudioEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
};

#endif // QAUDIOENCODERSETTINGSCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QAudioEncoderSettingsControl_shell.h <==
#ifndef QAUDIOENCODERSETTINGSCONTROL_SHELL_H
#define QAUDIOENCODERSETTINGSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudioencodersettingscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaencodersettings.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QAudioEncoderSettingsControl_shell : public QAudioEncoderSettingsControl, public QtJambiShellInterface
{
public:
    QAudioEncoderSettingsControl_shell(QObject* parent0 = nullptr);
    ~QAudioEncoderSettingsControl_shell() override;

    QAudioEncoderSettings audioSettings() const override;
    void childEvent(QChildEvent* event0) override;
    QString codecDescription(const QString& codecName0) const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setAudioSettings(const QAudioEncoderSettings& settings0) override;
    QStringList supportedAudioCodecs() const override;
    QList<int> supportedSampleRates(const QAudioEncoderSettings& settings0, bool* continuous1) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioEncoderSettingsControl_access : public QAudioEncoderSettingsControl
{
    jobject __qt_audioSettings_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_codecDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring codecName0) const;
    void __qt_setAudioSettings_cref_QAudioEncoderSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0);
    jobject __qt_supportedAudioCodecs_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_supportedSampleRates_cref_QAudioEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
};

#endif // QAUDIOENCODERSETTINGSCONTROL_SHELL_H
